[![CI](https://github.com/JannisNe/timewise/actions/workflows/continous_integration.yml/badge.svg)](https://github.com/JannisNe/timewise/actions/workflows/continous_integration.yml)
[![Coverage Status](https://coveralls.io/repos/github/JannisNe/timewise/badge.svg?branch=main)](https://coveralls.io/github/JannisNe/timewise?branch=main)
[![PyPI version](https://badge.fury.io/py/timewsie.svg)](https://badge.fury.io/py/timewise)


# `timewise` is great, love it!
Download infrared lightcurves recorded with the WISE satellite. More info soon!

## Installation

`timewise` is a python package, installable through `pip`
```
pip install timewise
```